@@ -68,9 +68,12 @@ _VALID_PROPERTIES = {
     "properties",
     "additionalProperties",
     "readOnly",
+    "writeOnly",
     "xml",
     "externalDocs",
     "example",
+    "nullable",
+    "deprecated",
 }
 
 
